@@ -92,6 +92,8 @@ __all__ = (
     "SiteTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateOutpostInputRequestTypeDef",
+    "UpdateOutpostOutputTypeDef",
     "UpdateSiteAddressInputRequestTypeDef",
     "UpdateSiteAddressOutputTypeDef",
     "UpdateSiteInputRequestTypeDef",
@@ -614,6 +616,37 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateOutpostInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateOutpostInputRequestTypeDef",
+    {
+        "OutpostId": str,
+    },
+)
+_OptionalUpdateOutpostInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateOutpostInputRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "SupportedHardwareType": SupportedHardwareTypeType,
+    },
+    total=False,
+)
+
+
+class UpdateOutpostInputRequestTypeDef(
+    _RequiredUpdateOutpostInputRequestTypeDef, _OptionalUpdateOutpostInputRequestTypeDef
+):
+    pass
+
+
+UpdateOutpostOutputTypeDef = TypedDict(
+    "UpdateOutpostOutputTypeDef",
+    {
+        "Outpost": "OutpostTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 UpdateSiteAddressInputRequestTypeDef = TypedDict(
     "UpdateSiteAddressInputRequestTypeDef",
     {
